@@ -70,7 +70,7 @@ public:
 void IfaceParser::parse(FILE* input, ScanConsumer& sc)
 	throw (Exception)
 {
-#define ATLINESTART "^[[:blank:]]*(guessnet[0-9]*[[:blank:]]+)?test[0-9]*(-| )"
+#define ATLINESTART "^[[:blank:]]*(guessnet[0-9]*[[:blank:]]+)?test[0-9]*(-|[[:blank:]]+)"
 #define MACPATTERN "[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}:[0-9A-Fa-f]{2}"
 	ExtendedRegexp null_line("^[[:blank:]]*(#.*)?$");
 	ExtendedRegexp iface_line(
@@ -97,6 +97,7 @@ void IfaceParser::parse(FILE* input, ScanConsumer& sc)
 	ExtendedRegexp old_default_line(
 		"^[[:blank:]]*guessnet[[:blank:]]+"
 		"default[[:blank:]]*$");
+	ExtendedRegexp generic_guessnet_line(ATLINESTART);
 	ExtendedRegexp parm_line(
 		"^[[:blank:]]*([^[:blank:]]+)[[:blank:]]+(.+)$", 2);
 	string profileName;
@@ -263,6 +264,10 @@ void IfaceParser::parse(FILE* input, ScanConsumer& sc)
 					Environment::get().defprof(profileName);
 				}
 			}
+			else if (generic_guessnet_line.match(line))
+			{
+				warning("Parse error at line %d: line ignored\n", linenum);
+			}
 			else if (parm_line.match(line))
 			{
 				//string name(line, parts[1].rm_so, parts[1].rm_eo - parts[1].rm_so);
