@@ -13,7 +13,8 @@ protected:
 public:
 	PacketMaker(NetSender& sender) : sender(sender) {}
 	
-	Buffer makeARPRequest(const IPAddress& ip) throw ();
+	Buffer makeARPRequest(const IPAddress& ip, const IPAddress& src) throw ();
+	Buffer makeDHCPRequest() throw ();
 };
 
 // vim:set ts=4 sw=4:
