@@ -28,19 +28,23 @@ void ScanBag::add(const Scan* scan) throw ()
 
 vector<string> ScanBag::notify(const Scan* scan) throw ()
 {
-	// For every candidate profile, check the signatures.  If one matches with
-	// `scan', remove it.  If no signature matches for a candidate, remove the
-	// candidate.  Return the list of candidates left.
+	// The candidate winnowing algorithm:
+	// For every candidate profile: if the profile has the scan
+	// with the signature of "scan" then remove that scan;
+	// otherwise remove the candidate.
+	// Return the list of candidates left.
+
 	//defaultProfile = "";
 	
-	vector<string> res;
+	vector<string> cands_left;
 	string sig = scan->signature();
 	for (iterator i = begin(); i != end(); )
 	{
 		set<string>::iterator j = i->second.find(sig);
 		if (j == i->second.end())
 		{
-			// If no signature matches for a candidate, remove the candidate
+			// This candidate has no scan with the signature
+			// so remove the candidate
 			iterator k = i;
 			k++;
 			erase(i);
@@ -48,23 +52,18 @@ vector<string> ScanBag::notify(const Scan* scan) throw ()
 		}
 		else
 		{
-			// If a profile has a signature matching with `scan', remove it
+			// This candidate has a scan with the signature
+			// so remove the matching scan
 			i->second.erase(j);
-			res.push_back(i->first);
+			cands_left.push_back(i->first);
 			i++;
 		}
 	}
-	return res;
+	return cands_left;
 }
 
 string ScanBag::getLessSpecific() const throw ()
 {
-	//if (defaultProfile.size() > 0)
-		return defaultProfile;
-
-/* Disabled, as it would be called in an ambiguous case, and returning the
- * default is a better option
-
 	string cand;
 	int count = -1;
 	for (const_iterator i = begin(); i != end(); i++)
@@ -76,7 +75,11 @@ string ScanBag::getLessSpecific() const throw ()
 		}
 	}
 	return cand;
-*/
+}
+
+string ScanBag::getDefault() const throw ()
+{
+		return defaultProfile;
 }
 
 void ScanBag::dump() const throw ()
