@@ -27,6 +27,9 @@ public:
 	/// Get the less specific profile among the available ones
 	std::string getLessSpecific() const throw ();
 
+	/// Get the default profile
+	std::string getDefault() const throw ();
+
 	/// Remove all items from this ScanBag
 	void clear() throw ()
 	{
