@@ -30,12 +30,16 @@ public:
 	virtual void notifyScan(const Scan* scan) throw () = 0;
 };
 
+/*
+ * A particular class of scanner handles all scans of the like-named type.
+ * It notifies listeners when a scan succeeds.
+ */
 class Scanner
 {
 protected:
 	ScannerListener* listener;
 
-	void found(const Scan* scan) throw ()
+	void succeeded(const Scan* scan) throw ()
 	{
 		listener->notifyScan(scan);
 	}
