@@ -2,7 +2,7 @@
 #define SCRIPT_SCANNER_H
 
 /*
- * Scanner that delegates scanning to an external script
+ * Tester that delegates testing to an external script
  *
  * Copyright (C) 2003  Enrico Zini <enrico@debian.org>
  *
@@ -38,6 +38,7 @@ protected:
 public: 
 	ScriptScanner(ProcessRunner runner, ScannerListener* listener) throw ()
 		: Scanner(listener), runner(runner) {}
+	virtual ~ScriptScanner() throw () {}
 
 	virtual void handleTermination(const std::string& signature, int status) throw ();
 	
