@@ -212,7 +212,7 @@ int main (int argc, const char *argv[])
 	try {
 		// Install the handler for unexpected exceptions
 		InstallUnexpected installUnexpected;
-		FILE* input = 0;
+		//FILE* input = 0;
 
 		/* Check if we have to bring up the interface; if yes, do it */
 		//iface_was_down = iface_init(Environment::get().iface(), op_init_time);
