@@ -33,6 +33,7 @@
 #include "PeerScanner.h"
 #include "ScriptScanner.h"
 #include "DHCPScanner.h"
+#include "ScanConsumer.h"
 #include "Mutex.h"
 #include "GuessnetEnvironment.h"
 #include "ScanBag.h"
@@ -70,7 +71,7 @@ protected:
 
 	int cand_count;
 
-	ScanBag scans;
+	ScanBag scanbag;
 
 public:
 	ScanRunner() throw () : cand_count(0) {}
@@ -79,18 +80,18 @@ public:
 	/// Get the number of candidate profiles
 	int candidateCount() const throw () { return cand_count; }
 	
-	/// Add `scan' to the list of tests to perform
+	/// Add to the list of tests to perform
 	virtual void handleScan(const Scan* scan) throw ()
 	{
-		scans.add(scan);
+		scanbag.add(scan);
 	}
 
-	/// Notify that the test `scan' has been successful
+	/// Handle notification that a test has been successful
 	virtual void notifyScan(const Scan* scan) throw ()
 	{
 		try {
 			MutexLock lock(waitMutex);
-			candidates = scans.notify(scan);
+			candidates = scanbag.notify(scan);
 			if (candidates.size() == 1)
 				waitCond.broadcast();
 		} catch (Exception& e) {
@@ -119,15 +120,21 @@ public:
 
 		if (candidates.size() == 1)
 			return candidates[0];
-		//else
-			//return scans.getLessSpecific();
+/*
+		else
+			return scanbag.getLessSpecific();
+*/
 
 		waitCond.wait(lock, abstime);
 
 		if (candidates.size() == 1)
 			return candidates[0];
+/*
 		else
-			return scans.getLessSpecific();
+			return scanbag.getLessSpecific();
+*/
+		else
+			return scanbag.getDefault();
 	}
 };
 
@@ -153,10 +160,10 @@ public:
 	void startScans() throw (SystemException, libnetException, pcapException)
 	{
 		printf("Scans contents:\n");
-		scans.dump();
+		scanbag.dump();
 		
-		for (list<const Scan*>::const_iterator i = scans.getScans().begin();
-				i != scans.getScans().end(); i++)
+		for (list<const Scan*>::const_iterator i = scanbag.getScans().begin();
+				i != scanbag.getScans().end(); i++)
 		{
 			const Scan* scan = *i;
 			if (const PeerScan* s = dynamic_cast<const PeerScan*>(scan))
@@ -206,7 +213,7 @@ public:
 		while (!_canceled)
 		{
 			int num = 1;
-			const list<const Scan*>& cands = scans.getScans();
+			const list<const Scan*>& cands = scanbag.getScans();
 			for (list<const Scan*>::const_iterator i = cands.begin();
 					i != cands.end(); i++)
 			{
@@ -257,7 +264,7 @@ protected:
 	{
 		if (peerScanner)
 			return;
-		verbose("Starting test subsystem\n");
+		verbose("Starting peer test subsystem\n");
 		startNetScanning();
 		peerScanner = new PeerScanner(*sender, this);
 		watcher->addARPListener(peerScanner);
@@ -267,7 +274,7 @@ protected:
 	{
 		if (scriptScanner)
 			return;
-		verbose("Starting external process test subsystem\n");
+		verbose("Starting command test subsystem\n");
 		runner = new ProcessRunner();
 		scriptScanner = new ScriptScanner(*runner, this);
 	}
@@ -276,7 +283,7 @@ protected:
 	{
 		if (dhcpScanner)
 			return;
-		verbose("Starting test subsystem\n");
+		verbose("Starting dhcp test subsystem\n");
 		startNetScanning();
 		dhcpScanner = new DHCPScanner(*sender, this);
 		watcher->addDHCPListener(dhcpScanner);
@@ -298,8 +305,8 @@ public:
 	
 	void startScans() throw (SystemException, libnetException, pcapException)
 	{
-		for (list<const Scan*>::const_iterator i = scans.getScans().begin();
-				i != scans.getScans().end(); i++)
+		for (list<const Scan*>::const_iterator i = scanbag.getScans().begin();
+				i != scanbag.getScans().end(); i++)
 		{
 			const Scan* scan = *i;
 			if (const PeerScan* s = dynamic_cast<const PeerScan*>(scan))
